@@ -12,11 +12,21 @@ class CMSPathsAdmin(admin.ModelAdmin):
 
 @admin.register(CMSContents)
 class CMSContents(admin.ModelAdmin):
-    list_display = ["id", "title","timestamp", "markup",]
-
+    list_display = ["id", "title","timestamp", "markup", "page"]
+    list_filter=["title","markup"]
+    
+    
+def make_published(modeladmin, request, queryset):
+    queryset.update(published=True)
+    
+make_published.short_description= "Publish Selected CMSEntries"
+    
 @admin.register(CMSEntries)
 class CMSEntries(admin.ModelAdmin):
-    pass
+    list_display = ['id', 'title', 'slug', 'path', 'page_type', 'published', 'frontpage']
+    list_filter =["page_type", "template"]
+    search_fields = ('title',)
+    actions = [make_published]
 
 @admin.register(CMSMarkUps)
 class CMSMarkUps(admin.ModelAdmin):
