@@ -31,6 +31,6 @@ class JqSplitDateTimeField(fields.MultiValueField):
                 raise forms.ValidationError("Field is missing data.")
             input_time = strptime("%s:%s %s"%(data_list[1], data_list[2], data_list[3]), "%I:%M %p")
             datetime_string = "%s %s" % (data_list[0], strftime('%H:%M', input_time))
-            print "Datetime: %s"%datetime_string
+            print("Datetime: %s"%datetime_string)
             return datetime_string
-        return None
\ No newline at end of file
+        return None
