@@ -1,6 +1,7 @@
-from . mycms_view  import YACMSViewObject
+from . mycms_view  import ViewObject
 from . category_page import CategoryPage
 from . multi_page import MultiPage
 from . single_page import SinglePage
 from . multi_page import MemberPage
+from . global_article_list import AllArticlesPage
 
