@@ -9,13 +9,17 @@ import os
 from PIL import Image
 import threading
 import datetime
+import faker
+import random
 
 from bs4 import BeautifulSoup
 import simplejson as json
 import threading
 import arrow
 from pathlib import Path
+from django.conf import settings
 
+from django.contrib.auth import logout
 from django.shortcuts import render, render_to_response
 from django.http import HttpResponse
 from django.contrib.sitemaps import Sitemap
@@ -24,10 +28,11 @@ from django.http import HttpResponseRedirect
 from django.http import HttpResponseServerError
 from django.views.decorators.csrf import csrf_exempt
 from django.views.generic import View
+from django import forms
 from django.forms.models import model_to_dict
 from django.http import Http404
+from django.http import HttpResponseServerError
 from django.core.files.uploadedfile import UploadedFile
-from django.forms.models import model_to_dict
 from django.utils.text import slugify
 from django.views.generic.base import View
 from django.utils.decorators import method_decorator
@@ -69,6 +74,9 @@ from django.conf import settings
 from django.http import HttpResponse
 from django.views.generic import CreateView, DeleteView, ListView
 
+
+from django_filters.rest_framework import DjangoFilterBackend
+
 from loremipsum import get_paragraphs
 from mycms.creole import creole2html
 
@@ -89,13 +97,14 @@ from mycms.models import CMSMarkUps
 from mycms.models import CMSTemplates
 from mycms.models import CMSPaths
 
-from mycms.view_handlers import YACMSViewObject
+
+from mycms.view_handlers import ViewObject
 
 
 
 from mycms.api import CMSContentsViewSet
 from mycms.api import CMSFormatterContent
-
+from mycms import funclib
 
 logger = logging.getLogger(name="mycms.views")
 
@@ -115,10 +124,7 @@ def  get_static_files_dir():
     else:
         raise Exception("""Static Files Dir Not Found. Please create a 'static' dir within the parent path.""")
 
-ASSETS_DIR = pathlib.Path(get_static_files_dir(),"assets")
 
-if not ASSETS_DIR.is_dir:
-    ASSETS_DIR.mkdir()
 
 
 class CMSFileUpload(View):
@@ -184,14 +190,26 @@ class CMSFileUpload(View):
         with mylock:
             from django.conf import settings
 
+            """
+            The files are uploaded to the assets directory. A directory is 
+            created with the same path as the article that the asset is 
+            uploaded to. For example an article at 
+            /foo/bar/baz will hvae all images uploaded to 
+            Path(settings.ASSETS_DIR, "foo/bar/baz/image)
+            """
+
             try:
-                assets_dir = settings.YACMS_SETTINGS.get("ARTICLE_IMAGES_DIR")
+                #A sanity check to make sure the assets dir exists.
+                #TODO: Decide if this code should really be here. IMHO the 
+                #test to make sure it exists should be elsewhere. 
+                assets_dir = settings.ASSETS_DIR
+                
             except AttributeError as e: 
-                print("ARTICLE_IMAGES_DIR IS NOT CONFIGURED! Falling back to default.")
-                assets_dir = os.path.join(settings.BASE_DIR, "static/assets")
+                print("ASSETS_DIR IS NOT CONFIGURED! Falling back to default.")
+                #TODO: Danger!! We assuming here that PARENT_DIR is defined. 
+                #What if the end user does not define it????
+                assets_dir = os.path.join(settings.PARENT_DIR, "assets/")
                         
-
-
             path = kwargs.get("path", None).lstrip("/")
 
             fullpath = pathlib.Path(pathlib.Path(assets_dir), path)
@@ -277,20 +295,47 @@ class CMSSitemap(Sitemap):
     def lastmod(self, obj):
         return obj.date_modified
 
+#Django 
+
+ 
+class CMSLoginForm(forms.Form):
+    username = forms.CharField(max_length=100, label="Username")
+    password = forms.CharField(max_length=32, widget=forms.PasswordInput)
 
 class CMSLoginView(View):
-
+    
     def get(self, request, **kwargs):
-        template_name = "mycms/Login.html"
-        return render_to_response(template_name,context_instance=RequestContext(request))
+        
+        next_page = request.GET.get("next", "")
+        
+        if not request.user.is_authenticated:
+            template_name = "mycms/Login.html"
+            
+            #also set a session variable to show the toolbar
+            request.session["show_toolbar"] = True
+            context = {"form": CMSLoginForm(), "next":next_page }
+            return render(request, template_name, context)
+        else:
+            return HttpResponseRedirect("/profile")
 
 
     def post(self, request, **kwargs):
 
         username = request.POST.get("username", None)
         password = request.POST.get("password", None)
-        next_page = request.GET.get("next")
+        
+        #Set the next page to a default if not given. 
+        next_page = request.GET.get("next", "/cms/user/articles")
 
+        #sanitize next_page
+        
+        if len(next_page) == 0:
+            next_page = "/profile"
+        
+        if not ( (next_page=="/") or next_page.startswith("/cms") or (next_page=="/profile")):
+            #We only allow redirects to cms contents or to /profile
+            self.log.info("redirect after login denied to: {}".format(next_page))
+        
         from django.contrib.auth import authenticate
         user = authenticate(username=username, password=password)
 
@@ -301,6 +346,9 @@ class CMSLoginView(View):
                 login(request, user)
                 if next_page is not None:
                     return HttpResponseRedirect(next_page)
+                else:
+                    #Go to the user's account page. 
+                    return HttpResponse(content=b'You are now logged in.')
             else:
                 print("The password is valid, but the account has been disabled!")
                 error_msg = "Account is disabled."
@@ -309,7 +357,23 @@ class CMSLoginView(View):
             error_msg = "The system was unable to verify the username and password."
 
         template_name = "mycms/Login.html"
-        return render_to_response(template_name,{ "error_msg": error_msg},context_instance=RequestContext(request))
+        return render(request, template_name,{ "error_msg": error_msg})
+
+
+class CMSUserProfileView(View):
+    
+    def get(self, request, **kwargs):
+        template_name = "mycms/Profile.html"
+        if not request.user.is_authenticated:
+            return HttpResponseRedirect("/login")
+        else:
+            return render(request, template_name)
+    
+
+class CMSUserAdminPagesView(View):
+    
+    def get(self, request, **kwargs):
+        pass
 
 
 
@@ -317,18 +381,38 @@ class CMSLogoutView(View):
 
     def get(self, request, **kwargs):
         logout(request)
-        #template_name = "mycms/Login.html"
-        #return render_to_response(template_name,context_instance=RequestContext(request))
+        template_name = "mycms/Logout.html"
+     
+        #So lets log the user out.
+        
+        if request.user.is_active:
+            logout(request)
+            
         return HttpResponseRedirect("/login/")
+        
 
 class CMSFrontPage(View):
 
     def get(self, request, **kwargs):
 
-        #template_name = "mycms/Index.html"
-        template_name = "mycms/index.html"
-        #return render(template_name,context_instance=RequestContext(request) )
-        return render(request, template_name)
+        template_name = "mycms/Index.html"
+        
+        #TODO: Fix this hack. We create a fake view_object for the frontpage
+        #so that we can pass a few template data. 
+        
+        class View_Object():
+            pass
+        
+        view_object = View_Object()
+        
+        if settings.FORCE_SHOW_ADVERTS or (settings.DEBUG == False):
+            view_object.SHOW_ADVERTS = True
+        else:
+            print("SHOW_ADDS_IS FALSE") 
+            view_object.SHOW_ADVERTS = False
+       	 
+        print("FORCE_SHOW_ADVERTS={},DEBUG={},SHOW_ADDS={}".format(settings.FORCE_SHOW_ADVERTS, settings.DEBUG, view_object.SHOW_ADVERTS) )
+        return render(request, template_name, { "view_object": view_object})
 
 
 class LoremIpsumAPIView(APIView):
@@ -550,7 +634,7 @@ class CMSEntriesAPIView(APIView):
     authentication_classes = (SessionAuthentication, BasicAuthentication)
     permission_classes = (IsAuthenticated,)
 
-    filter_backends = (filters.DjangoFilterBackend,)
+    filter_backends = (DjangoFilterBackend,)
 
     def get(self, request, **kwargs):
         """
@@ -786,7 +870,7 @@ class CMSContentsAPIView(APIView):
                 cmscontent_dict = model_to_dict(cmscontent_object)
 
 
-                #We need to get the html. So We need the freaking YACMSViewObject.
+                #We need to get the html. So We need the freaking ViewObject.
 
 
 
@@ -822,82 +906,219 @@ class CMSIndexView(APIView):
         pass
 
 
+class CMSArticleListsView(View):
+    """
+    Implements a paginated list view of all published articles. 
+    """
+    from django.db.models import Q
+    
+    def get(self,request, **kwargs):
+        
+        obj_list = CMSEntries.objects.filter((Q(page_type = singlepageview_pagetype_obj) | Q(page_type = multipageview_pagetype_obj)) &
+                                             Q(path__parent__id = self.page_object.path.id))[start: start+page_size]
+        #wrap the entries of the obj_list into their view_handler representations
+        view_list = []
+        
+        
+        for obj in obj_list:
+            view_list.append(ViewObject(page_object=obj))
+
+        return view_list
+    
+    
+
 class CMSPageView(View):
     """
-    The main interface to the website.
+    The main interface to the website. This view serves all of the web pages
+    except pages served by:
+    
+        CMSArticleListsView.    
+        CMSIndexView
+        CMSFrontPage
     """
 
-    def get_object(self,**kwargs):
+    def get_object(self,request, **kwargs):
         """
-        returns a YACMSViewObject
+        This method gets the cmsentries object from the database. 
         """
+        
+        
         path = kwargs.get("path", None)
         page_id = kwargs.get("page_id", None)
 
-        try:
-            if path:
-                obj = YACMSViewObject(path=path)
+        
+        """
+        We use the path to search for the object if it is provided. Otherwise
+        we can also load the page via page_id. If none is provided then 
+        we just want to load the root. 
+        """
+        
+        try: 
+            if path:    
+                obj = ViewObject(path=path, request=request)
+            
             elif page_id:
-                obj = YACMSViewObject(page_id=page_id)
+                obj = ViewObject(page_id=page_id, request=request)
             else:
-                #Lets make path = "/" as default.
-                obj = YACMSViewObject(path=u"/")
+                """
+                If no path or page_id is given then we just load /
+                The path /  is the global cmsentries list which is 
+                the root of the CMS. This root is created by default on 
+                first access.  It is created as ALLARTICLES page_type.
+                """
+                obj = ViewObject(path="/", request=request)
+                
             return obj
 
         except ObjectDoesNotExist as e:
+            """
+            Handle special case where we are in the root of the CMS i.e. /cms/
+            """
+            if path in [None , "/", "about"]:
+                """
+                / and /about are special pages in that they shoud be created
+                if they do not yet exist. 
+                """
+                if path is None:
+                    path = "/"
+                elif not path.startswith("/"):
+                    path = "/"+path
 
-            if (path is None) or (path == u"/"):
-                #we are in /cms and it does not exist. We create it!!
+                """This code is obsolete. we are now creating all the 
+                required pagetypes on first import of mycms.view_handlers.page_types"""
 
+                #"""
+                path_obj,_ = CMSPaths.objects.get_or_create(path=path)
 
-                path_obj,_ = CMSPaths.objects.get_or_create(path="/")
-
+                if path == "/about":
+                    page_type = "SINGLEPAGE"
+                    title = "About"
+                    text = funclib.get_fake_contents(random.randint(3,5))
+                    slug = "about"
+                else:
+                    page_type ="ALLARTICLES"
+                    title = "MyCMS - Yet Another CMS"
+                    text = "MYCMS Main Page Content. This is not shown in a default Category Page Template"
+                    slug = ""
                 try:
-                    pagetype_obj, _ = CMSPageTypes.objects.get_or_create(page_type="CATEGORY",
-                                                                      text = "Category Page",
-                                                                      view_class = "CategoryPage",
-                                                                      view_template = "CategoryPage.html"
-                                                                      )
-                except MultipleObjectsReturned as e:
-
-                    logger.warn("Multiple PageType: CATEGORY found. Database is inconsistent. Returning the first one found.")
-                    pagetype_obj = CMSPageTypes.objects.filter(page_type="CATEGORY")[0]
-
-
+                    pagetype_obj, _ = CMSPageTypes.objects.get_or_create(page_type=page_type)
+                
+                except Exception as e: 
+                   
+                    logger.warn("Multiple PageType {} found in database")
+                    return HttpResponseServerError("Server Error: Your favourite devops is getting woken up.")
+         
                 try:
                     entry_obj, c= CMSEntries.objects.get_or_create(page_type=pagetype_obj,
                                                                  path=path_obj,
-                                                                 title="Yet Another CMS.")
+                                                                 title=title,
+                                                                 slug = slug)
+
+                    if c:
+                        #We also need to create a content object to attach to entry_obj
+                        content_object = CMSContents()
+                        content_object.content = text
+                        content_object.meta_description = "myCMS - A django based cms"
+                        
+                        markup_obj, c = CMSMarkUps.objects.get_or_create(markup="Creole")
+                        content_object.markup = markup_obj
+                        
+                        content_object.save()
+                        entry_obj.content.add(content_object)
+                        entry_obj.save()
+
                 except MultipleObjectsReturned as e:
                     msg = "Multiple CMSEntries for /cms found. Database is inconsistent. Using the first one found. "
                     logger.warn(msg)
 
                     entry_obj = CMSEntries.objects.filter(path=path_obj)[0]
-
-
-
-                obj = YACMSViewObject(path=u"/")
+                obj = ViewObject(path=path)
                 return obj
             else:
+                
+                #TODO: Make sure to log this too 
                 raise Http404("Page Does Not Exist.")
 
 
 
     def get(self,request, **kwargs):
-        """Just get the page and return it."""
-        
+        """
+        The main entry point to the frontend of the CMS. 
+        All website user pages are obtained through this method."""
+    
         get = request.GET
         
-        show_toolbar = "toolbar" in request.GET.keys()
+        """
+        Whenever ?toolbar is added to the get parameter, we save it to the session
+        This is used as a flag to show the files. 
+        """
+        toolbar = request.GET.get("toolbar", None)
+        if toolbar and toolbar.upper() == "TRUE":
+            request.session["show_toolbar"] = True
+        elif toolbar and toolbar.upper() == "FALSE":
+            request.session["show_toolbar"] = False
         
-        obj = self.get_object(**kwargs)
+        login = request.GET.get("login", None)
+        logout = request.GET.get("logout", None)
+        
+        if login:
+            """
+            When a page is requested with ?login=X where X can be anything, we 
+            redirect them to the login page which will send it back to this 
+            page once logged in. 
+            """
+            
+            #But only do it if user is not yet logged in
+            if not request.user.is_authenticated:
+                #so redirecto user to log in page and give our path to come back to
+                return HttpResponseRedirect("/cms/login/?next={}".format(request.path))
+        
+            else:
+                """
+                The user is not logged in. 
+                """
+                
+                ###
+                #TODO: Implement a message to the user that he is already logged in.
+                ###
+                
+                #For now do dnothing
+                pass
+            
+        if logout and request.user.is_authenticated:
+            #jist logout the current user and send him to the logout. 
+                return HttpResponseRedirect("/cms/logout/")
+            
+        #get object will load return an instance of mycms.view_handlers.ViewObject
+        #which encapsulates the CMSEntry and all other operations on it. 
+        obj = self.get_object(request, **kwargs)
         obj.request = request
-        obj.show_toolbar = show_toolbar
+        
+        #Save the toolbar value in the session in the show_toolbar member variable so 
+        #that it can be accessible in the web page template code. 
+        obj.show_toolbar = request.session.get("show_toolbar", False) 
+        
+        
         
         template = obj.template
+       
+        if settings.DEBUG:
+            from mycms.view_handlers import page_types
+            return render_to_response(template, {"view_object": obj})
+        else:
         
-        return render_to_response(template, {"view_object": obj})
-
+            try:
+                return render_to_response(template, {"view_object": obj})
+                
+            except Exception as e:
+                
+                #if we are in debug mode then show then let django handle showing 
+                #the debug error:
+                msg = "Application Error {}".format(e)            
+                return HttpResponse(content=bytes(msg, 'utf-8'), status=500)
+            
+        
+    
     def post(self, request, **kwargs):
         print(request, kwargs)
         return HttpResponse("Not implemented")
@@ -934,58 +1155,63 @@ class  AssetsUploaderView(View):
         else:
             head, tail = os.path.split(newdir)
             if head and not os.path.isdir(head):
-                self._mkdir(head)
+                try:
+                    self._mkdir(head)
+                except FileExistsError as e:
+                    pass
+                
             #print "_mkdir %s" % repr(newdir)
             if tail:
-                os.mkdir(newdir)
-
+                try:
+                    os.mkdir(newdir)
+                except FileExistsError as e:
+                    pass
+                
     #----------------------------------------------------------------------
     def  get(self, request, **kwargs):
 
         """
-        We assume we have a GET
-        According to https://github.com/blueimp/jQuery-File-Upload/wiki/Setup
-        we have to return a list of the images in the dir as follows:
-
-
-
-        {"files": [
-          {
-            "name": "picture1.jpg",
-            "size": 902604,
-            "url": "http:\/\/example.org\/files\/picture1.jpg",
-            "thumbnailUrl": "http:\/\/example.org\/files\/thumbnail\/picture1.jpg",
-            "deleteUrl": "http:\/\/example.org\/files\/picture1.jpg",
-            "deleteType": "DELETE"
-          },
-          {
-            "name": "picture2.jpg",
-            "size": 841946,
-            "url": "http:\/\/example.org\/files\/picture2.jpg",
-            "thumbnailUrl": "http:\/\/example.org\/files\/thumbnail\/picture2.jpg",
-            "deleteUrl": "http:\/\/example.org\/files\/picture2.jpg",
-            "deleteType": "DELETE"
-          }
-        ]}
+        Creates the javascript to load the Krajee file upload.
+        
+        This needs to return a configuration like
+        
+        
+        {
+            error: 'An error exception message if applicable',
+            errorkeys: [], // array of thumbnail keys/identifiers that have errored out (set via key property in initialPreviewConfig
+            initialPreview: [
+            ], // initial preview configuration 
+            initialPreviewConfig: [
+                // initial preview configuration if you directly want initial preview to be displayed with server upload data
+            ],
+            initialPreviewThumbTags: [
+                // initial preview thumbnail tags configuration that will be replaced dynamically while rendering
+            ],
+            append: true // whether to append content to the initial preview (or set false to overwrite)
+        }
         """
+        
 
-        try:
-            assets_dir = settings.YACMS_SETTINGS.get("ARTICLE_IMAGES_DIR")
-        except AttributeError as e: 
-            print("ARTICLE_IMAGES_DIR IS NOT CONFIGURED! Falling back to default.")
-            assets_dir = os.path.join(settings.BASE_DIR, "static/assets")
+        assets_dir = self.get_assets_dir()
     
         
-        path = kwargs.get("path", None).lstrip("/")
+        path = kwargs.get("path", "").lstrip("/")
         fullpath = pathlib.Path(pathlib.Path(assets_dir), path)
 
-        files = []
+
+        initialPreviewConfig = []
+        initialPreview = []
+        key = 0        
 
         print(fullpath.as_posix())
         try:
             filenames = os.listdir(fullpath.as_posix())
         except OSError as e:
-            return  JsonResponse({'files': []})
+            #This means that there is no directory yet. Nothing uploaded
+            #at all
+            return JsonResponse({'initialPreviewConfig': initialPreviewConfig,
+                                 "initialPreview": initialPreview})            
+
 
         for filename in filenames:
 
@@ -998,34 +1224,84 @@ class  AssetsUploaderView(View):
                 thumbnail_url = "/static/assets/{}/thumbnails/{}".format(path, filename)
                 delete_url = "/cms/{}/assets_manager/{}".format(path, filename)
 
+                print("*"*80)
+               
+                initial_pconf_entry = {
+                    "caption": filename,
+                    "size": stat.st_size,
+                    "width":"512px",
+                    "url": request.path,
+                    "key": filename
+                }
+                              
+                key = key + 1
+                
+                initialPreviewConfig.append(initial_pconf_entry)
+                initialPreview.append(image_url)
+                
+        return JsonResponse({'initialPreviewConfig': initialPreviewConfig,
+                             "initialPreview": initialPreview,
+                             "append":False})
 
-                file_dict = { "name": filename ,
-                              "size": stat.st_size,
-                              "url": image_url,
-                              "thumbnailUrl": thumbnail_url,
-                              "deleteUrl": delete_url,
-                              "deleteType": "DELETE" }
 
-                files.append(file_dict)
-
-        return JsonResponse({'files': files})
+    def get_assets_dir(self):
+        try:
+            assets_dir = settings.ASSETS_DIR
+        except AttributeError as e: 
+            print("ASSETS_DIR IS NOT CONFIGURED! Falling back to default.")
+            assets_dir = os.path.join(settings.BASE_DIR, "static/assets")
+        return assets_dir
 
 
     #----------------------------------------------------------------------
-    def  post(self, request, **kwargs):
+    def  post(self, request,*args, **kwargs):
         """"""
-        return self.fileupload(request, **kwargs)
+        
+        
+        filename = request.POST.get("key", None)
+        print(request.GET)
+        print(request.POST)
+        
+    
+        if filename is not None:
+    
+            #if we are getting a "{'key': ['0']} in the request.POST then it 
+            #means the user wants to delete a file.             
+            return self.filedelete(kwargs, filename)
+
+        else:    
+        #if we are getting a {'file_id': ['0']}> then it means its a fileupload
+            return self.fileupload(request, *args,**kwargs)
+
+    def filedelete(self, kwargs, filename):
+        path = kwargs.get("path", None).lstrip("/")
+        fullpath = pathlib.Path(pathlib.Path(self.get_assets_dir()), path)
+    
+        p_filename = pathlib.Path(fullpath, filename)
+    
+        logger.debug("Going to delete, {}".format(p_filename.as_posix()))
+    
+        try:
+            os.remove(p_filename.as_posix())
+            return JsonResponse({ } )
+    
+        except Exception as e:
+        
+            return JsonResponse({"error":"Failed to delete"}, status=status.HTTP_410_GONE)            
 
 
-    def fileupload(self,request, **kwargs):
+    def fileupload(self,request, *args,**kwargs):
 
         mylock = threading.Lock()
+        print(request.GET)
+        print(request.POST)
 
         with mylock:
             from django.conf import settings
-            assets_dir = ASSETS_DIR
+            assets_dir = self.get_assets_dir()
             path = kwargs.get("path", None).lstrip("/")
-
+            
+            
             fullpath = pathlib.Path(pathlib.Path(assets_dir), path)
 
             if not fullpath.exists():
@@ -1037,13 +1313,17 @@ class  AssetsUploaderView(View):
             thumbnailpath = pathlib.Path(fullpath, "thumbnails")
 
             if not thumbnailpath.exists():
-                os.makedirs(thumbnailpath.as_posix())
+                try:
+                    os.makedirs(thumbnailpath.as_posix())
+                except FileExistsError as e:
+                    #It must have been created by another thread. 
+                    pass
             elif not thumbnailpath.is_dir():
                 #Fix this to return a proper json response.
                 return HttpResponse("Error. Not full dir")
 
             if request.method == "POST":
-                uploaded_file = request.FILES.get("files[]")
+                uploaded_file = request.FILES.get("file_data")
 
                 filename = uploaded_file.name
 
@@ -1082,16 +1362,31 @@ class  AssetsUploaderView(View):
                                   "deleteUrl": delete_url,
                                   "deleteType": "DELETE" }
 
+                
+                initial_pconf_entry = {
+                    "caption": filename,
+                    "size": 1024,
+                    "width":"512px",
+                    "url": image_url,
+                    "key": filename
+                }
+                
+                
+                initialPreviewConfig = []
+                
+                
+
+
                 files.append(file_dict)
                 
-                return JsonResponse({'files': files})
-
+                #return JsonResponse({'files': files})
+                return self.get(request,*args, **kwargs)
     #----------------------------------------------------------------------
     def  delete(self,request, **kwargs):
         """"""
         path = kwargs.get("path", None).lstrip("/")
         filename=kwargs.get("filename",None).lstrip("/")
-        fullpath = pathlib.Path(pathlib.Path(ASSETS_DIR), path)
+        fullpath = pathlib.Path(pathlib.Path(self.get_assets_dir()), path)
 
 
         p_filename = pathlib.Path(fullpath, filename)
@@ -1180,9 +1475,10 @@ from django.http import HttpResponse
 from django.shortcuts import render
 from django.views import View
 import os
+from django.template import loader, Context
 
 
-class TemplateSampleLoader(View):
+class MockupLoader(View):
 
     def get(self, request, **kwargs):
 
@@ -1193,13 +1489,51 @@ class TemplateSampleLoader(View):
         else:
             #Return a list of html files in bootstrap_templates
 
-            bootstrap_examples_dir = os.path.join(settings.BASE_DIR, "templates/")
-
+            mockups_dir= os.path.join(settings.BASE_DIR, "mockups/")
+         
             files = []
-            for filename in os.listdir(path=bootstrap_examples_dir):
+            for filename in os.listdir(path=mockups_dir):
                 if filename.endswith(".html"):
                     files.append(filename)
 
-            return render(request, "bootstrap_templates.html", { "files": files})
+                    
+
+            return render(request, "mockups_index.html", { "files": files})
+        
+
+class LogoViewer(View):
+
+    
+    pass
 
 
+
+class CMSPreviewAPIView(View):
+    
+    def get(self, request):
+        raise NotImplementedError("This method is not supported")
+        
+    def post(self, request):
+        #We expect to recieve unformatted text and we shall 
+        #return it formatted.
+        
+        #For now it is assumed this is Creole 
+        pass
+        
+    
+    
+class CMSEntriesContentAreaFilter(forms.Form):
+    pass
+    
+    
+class CMSUserContentArea(View):
+    """This is a list view with filter."""
+    
+    
+    def get(self, request):
+        
+    
+    
+        return render(request, "mycms/CMSUserContentArea.html")
+    
+    
